package eu.maiora.routes

import eu.maiora.model.ViewEcommercePrezSconDisp
import eu.maiora.model.ViewEcommercePrezSconDispRepository
import eu.maiora.model.ViewEcommerceValoreUsatoRepository
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.auth.*
import io.ktor.server.response.*
import io.ktor.server.routing.*

fun Route.prezziScontiMagazzino(viewEcommerceValoreUsatoRepository: ViewEcommerceValoreUsatoRepository,
                                viewEcommercePrezSconDispRepository: ViewEcommercePrezSconDispRepository){
    route("/api/prezziScontiMagazzino"){
        authenticate("auth-jwt") {
            get(){
                // Ottieni l'id articolo dal percorso
                val idArticolo = call.parameters["idArticolo"]
                // Ottieni l'id cliente dal percorso
                val idCliente = call.parameters["idCliente"]

                if (idArticolo.isNullOrEmpty()) {
                    call.respondText("ID articolo non valido", status = HttpStatusCode.BadRequest)
                    return@get
                }

                if (idCliente.isNullOrEmpty()) {
                    call.respondText("ID cliente non valido", status = HttpStatusCode.BadRequest)
                    return@get
                }


                val dataValoreUsato = viewEcommerceValoreUsatoRepository.getValoreByIdArtIdClie(idCliente.toLong(), idArticolo.toLong())
                if(!dataValoreUsato.isNullOrEmpty() && dataValoreUsato.size == 1){
                    val data = viewEcommercePrezSconDispRepository.disponibilitaByIdArtIdClie(idCliente.toLong(), idArticolo.toLong())
                    if(!data.isNullOrEmpty()){
                        var listaElementiConValoreUsato = ArrayList<ViewEcommercePrezSconDisp>()
                        data.forEach { e ->
                            val nuovoElemento = e.copy(valoreCarcassa = dataValoreUsato[0].valoreUsato)
                            listaElementiConValoreUsato.add(nuovoElemento)
                        }
                        call.respond(listaElementiConValoreUsato)
                    }
                    else {
                        call.respondText("Articolo ecommerce non trovato (prezzi sconti e disponibilita)", status = HttpStatusCode.NotFound)
                    }
                }
                else {
                    if(dataValoreUsato.isNullOrEmpty()){
                        call.respondText(
                            "Errore nel recupero del valore usato. Nessun record trovato. idArticolo:$idArticolo - idCliente:$idCliente",
                            status = HttpStatusCode.NotFound)
                    }
                    else if(dataValoreUsato.size > 1){
                        call.respondText(
                            "Errore nel recupero del valore usato. Trovati record multipli. idArticolo:$idArticolo - idCliente:$idCliente",
                            status = HttpStatusCode.NotFound)
                    }

                }









                call.respond("OK")
            }
        }
    }
}